"use strict";
/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OTLPProtoExporterBrowserBase = void 0;
const api_1 = require("@opentelemetry/api");
const types_1 = require("../types");
const otlp_exporter_base_1 = require("@opentelemetry/otlp-exporter-base");
const root = require("../../generated/root");
/**
 * Collector Exporter abstract base class
 */
class OTLPProtoExporterBrowserBase extends otlp_exporter_base_1.OTLPExporterBrowserBase {
    constructor(config = {}) {
        super(config);
    }
    _getExportRequestProto(clientType) {
        if (clientType === types_1.ServiceClientType.SPANS) {
            // eslint-disable-next-line
            return root.opentelemetry.proto.collector.trace.v1.ExportTraceServiceRequest;
        }
        else {
            // eslint-disable-next-line
            return root.opentelemetry.proto.collector.metrics.v1.ExportMetricsServiceRequest;
        }
    }
    send(objects, onSuccess, onError) {
        if (this._shutdownOnce.isCalled) {
            api_1.diag.debug('Shutdown already started. Cannot send objects');
            return;
        }
        const serviceRequest = this.convert(objects);
        const exportRequestType = this._getExportRequestProto(this.getServiceClientType());
        const message = exportRequestType.create(serviceRequest);
        if (message) {
            const body = exportRequestType.encode(message).finish();
            if (body) {
                (0, otlp_exporter_base_1.sendWithXhr)(new Blob([body], { type: 'application/x-protobuf' }), this.url, Object.assign(Object.assign({}, this._headers), { 'Content-Type': 'application/x-protobuf', Accept: 'application/x-protobuf' }), this.timeoutMillis, onSuccess, onError);
            }
        }
        else {
            onError(new otlp_exporter_base_1.OTLPExporterError('No proto'));
        }
    }
}
exports.OTLPProtoExporterBrowserBase = OTLPProtoExporterBrowserBase;
//# sourceMappingURL=OTLPProtoExporterBrowserBase.js.map