"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _logger = require("./logger");

var _LoggingService = require("./services/LoggingService");

const config = require("./config");

const serviceLoader = require('./ServiceLoader');

class TriggerServices {
  constructor() {
    this.locationServices = {};
    this.collectionServices = {};
    this.loadServices();
  }

  getService(name) {
    return this.locationServices[name];
  }

  removeAug(augId) {
    for (let name in this.locationServices) {
      this.locationServices[name].removeAug(augId);
    }
  }

  removeAugfromInspector(augId) {
    for (let name in this.locationServices) {
      this.locationServices[name].removeAugfromInspector(augId);
    }
  }

  reapplyAugAfterTemporaryRemoval(aug) {
    for (let name in this.locationServices) {
      this.locationServices[name].reapplyAugAfterTemporaryRemoval(aug);
    }
  }

  removeAugTemporarily(augId, duration) {
    for (let name in this.locationServices) {
      this.locationServices[name].removeAugTemporarily(augId, duration);
    }
  }

  clearAugs() {
    for (let name of Object.keys(this.locationServices)) {
      this.locationServices[name].clearAugs();
    }
  }

  start() {
    this.loadServices();
  }

  async close() {
    const locationServicesToClose = [...Object.values(this.locationServices)];
    const collectionServicesToClose = [...Object.values(this.collectionServices)];
    this.locationServices = {};
    this.collectionServices = {};

    for (let location_service of locationServicesToClose) {
      await location_service.close();
    }

    for (let collection_service of collectionServicesToClose) {
      collection_service.close();
    }
  }

  loadLoggingService() {
    if (config.LogHandlerService.ENABLED) {
      try {
        _logger.logger.debug('Starting Logging Service');

        let loggingService = new _LoggingService.LoggingService();
        loggingService.start();
        return loggingService;
      } catch (e) {
        _logger.logger.exception("Error starting logging service", e);
      }
    }
  }

  loadService(service) {
    let serviceHandle = service.func();

    if (serviceHandle === undefined) {
      return;
    }

    if (service.location) {
      this.locationServices[service.name] = serviceHandle;
    } else {
      this.collectionServices[service.name] = serviceHandle;
    }
  }

  loadServices() {
    for (const service of serviceLoader.default) {
      this.loadService(service);
    }

    const sharedServices = [{
      'name': 'loggingService',
      'func': this.loadLoggingService,
      'location': true
    }];

    for (const service of sharedServices) {
      this.loadService(service);
    }
  }

}

exports.default = TriggerServices;