"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _logger = require("../logger");

var _configUpdater = require("../configUpdater");

var _utils = require("../utils");

const config = require("../config");

class CommandHandler {
  constructor(agentCom, augManager) {
    this.agentCom = agentCom;
    this.augManager = augManager;
    this.agentCom.on("InitialAugsCommand", initialAugs => this._handleInitialAugs(initialAugs));
    this.agentCom.on("AddAugCommand", command => this._handleAddAug(command));
    this.agentCom.on("RemoveAugCommand", command => this._handleRemoveAug(command));
  }

  async _handleInitialAugs(initialAugs) {
    try {
      _configUpdater.ConfigUpdater.updateConfig(initialAugs.getSdkConfigurationMap(), config);
    } catch (err) {
      _logger.logger.exception("Failed to update configuration", err);
    }

    let augs = [];

    for (const aug of initialAugs.getAugsList()) {
      let augConfig = JSON.parse(aug);
      augs.push(augConfig);
    } // Make sure utils have finished initializing before accessing augs


    await (0, _utils.initUtils)();
    this.augManager.initializeAugs(augs);
  }

  async _handleAddAug(command) {
    this.augManager.addAug(JSON.parse(command.getAugJson()));
  }

  async _handleRemoveAug(command) {
    this.augManager.removeAug(command.getAugId());
  }

}

exports.default = CommandHandler;