"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _WebsocketClient_base = _interopRequireDefault(require("./WebsocketClient_base"));

var _isomorphicWs = _interopRequireDefault(require("isomorphic-ws"));

var _exceptions = require("../exceptions");

var _logger = require("../logger");

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class WebsocketClient extends _WebsocketClient_base.default {
  connect() {
    return new Promise((resolve, reject) => {
      try {
        this.setPromiseHandlers(resolve, reject);
        /* TODO: Format URL to include token in URL itself */

        this.url += "?rookout-token=" + this.token;
        this._connection = new _isomorphicWs.default(this.url);
        this._connection.binaryType = "arraybuffer";
        this.setConnectTimeout();
        this.setResponseListeners();
      } catch (e) {
        reject(e);
      }
    });
  }

  sendInner(message, timeout, resolve, reject) {
    try {
      this._connection.send(message.buffer);

      resolve();
      clearTimeout(timeout);
    } catch (e) {
      reject(new _exceptions.RookSendFailedError());
      clearTimeout(timeout);
    }
  }

  terminateConnection() {
    if (this._connection) {
      this._connection.close();
    }

    this._connection = null;
  }

  setResponseListeners() {
    this._connection.onopen = () => {
      try {
        _logger.logger.debug("Connection established");

        this.clearConnectTimeout(); // The socket does not exist before this point except internally - we can't access it.
        // Upon a connection timeout (currently 2 seconds), the socket will be terminated.

        if (this._connection) {
          (0, _utils.nodeUnref)(this._connection._socket);
        }

        this.returnConnected();
      } catch (e) {}
    };

    this._connection.onclose = event => {
      try {
        this.returnError('Connection closed (' + event.code + '): ' + event.reason);
      } catch (e) {}
    };

    this._connection.onmessage = msg => {
      try {
        const res = new Uint8Array(msg.data);
        this.returnMessage(res);
      } catch (e) {
        console.error(e);
      }
    }; // Connection errors (e.g. abrupt termination)


    this._connection.onerror = err => {
      try {
        this.returnError(err);
      } catch (e) {}
    };
  }

}

exports.default = WebsocketClient;